/************************************************************************
 *   IRC - Internet Relay Chat, modules/database/database.c
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include "config.h"
#include "msg.h"
#include "modules.h"
#include "parse.h"
#include "database.h"
#include "db_internals.h"
#include "s_conf.h"
#include "ccr.h"
#include "ircd.h"
#include "hooks.h"

MODULE("database")

static struct module_handle *mh;
static char desc[] = "Database subsystem";
static char _version[] = RELEASE;

mod_deinit_func database_deinit;

#ifdef STATIC_MODULES
struct module_handle *
database_init(void)
#else
struct module_handle *
_modinit(void)
#endif
{
  if (match_ip_drop != NULL)
    return NULL;

  if (!(mh = register_module(_name, desc, _version, &database_deinit)))
    return NULL;

  init_ip_drop_table();

  if (open_databases() != 0)
    {
      deregister_module(mh, -1);
      return NULL;
    }

  if (seed_database)
    {
      struct client_connect_record ccr;
      memset(&ccr, 0, sizeof(ccr));
      ccr.host = "*";
      ccr.when = CurrentTime;
      ccr.placed_by = me.name;
      ccr.priority = 65535;
      ccr.reason = "Database seed - CHANGE THIS!";
      store_allow_ccr(&ccr);

      seed_database = 0;
    }

  match_ip_drop = _match_ip_drop;

  return mh;
}

void
database_deinit(int type)
{
  close_databases();
}
